@@ -76,7 +76,7 @@ from de.setup_project import (
     code_file_version, pev_str, pev_val, project_env_vars)
 
 
-__version__ = '0.2.6'
+__version__ = '0.2.7'
 
 
 # --------------- global constants ------------------------------------------------------------------------------------
@@ -441,12 +441,6 @@ def project_dev_vars(project_path: str = "") -> PdvType:
     project_path = pdv_str(pdv, 'project_path')     # re-read as absolute path
     sep = os.linesep
 
-    # RTD-build is failing if the Sphinx dependency is included without a pinned version (RTD default is 1.8.5).
-    # RTD-build default for sphinx_rtd_theme is <0.5 (0.4.3 get used), pin to current version 0.5.2
-    pdv['docs_requirements'] = \
-        sep.join(("sphinx==4.1.1", "sphinx_autodoc_typehints", "sphinx-rtd-theme==0.5.2", "sphinx_paramlinks")) \
-        if not namespace_name or is_root else ""                                # templates/..._test_requirements.txt
-
     pdv['prj_id'] = "_".join(pdv_str(pdv, _) for _ in ('repo_domain', 'repo_group', 'package_name', 'package_version'))
     pdv['project_name'] = " ".join(pdv_str(pdv, _) for _ in ('package_name', 'project_type', 'package_version'))
     pdv['project_parent'] = _project_parent_path(pdv)   # empty if project/package is not installed as editable/develop
@@ -888,7 +882,7 @@ def _check_types_linting_tests(pdv: PdvType):
         os.makedirs(".pylint", exist_ok=True)
         if is_portion and 'CI_PROJECT_ID' in os.environ:
             # gitlab pylint err: de/__init__.py:1:0: F0010: error while code parsing: Unable to load file de/__init__.py
-            _cl(62, f"touch {namespace_name}/__init__.py")
+            _cl(62, f"touch {namespace_name}/{PY_INIT}")
         out: List[str] = []
         _cl(62, f"pylint --output-format=text --max-line-length={line_len} {ignore_options} {' '.join(args)}",
             _exit_on_err=False, lines_output=out)   # alternative to _exit_on_err: run pylint with option --exit-zero
@@ -1230,6 +1224,8 @@ def _print_pdv(pdv: PdvType):
                                        for preset, dep_packages in pdv['portions_presets'].items()]
         pdv['project_packages'] = " ".join(pdv['project_packages'])
         pdv['project_resources'] = " ".join(pdv['project_resources'])
+        pdv['dev_require'] = " ".join(pdv['dev_require'])
+        pdv['docs_require'] = " ".join(pdv['docs_require'])
         pdv['setup_require'] = " ".join(pdv['setup_require'])
         pdv['tests_require'] = " ".join(pdv['tests_require'])
 
@@ -1350,10 +1346,11 @@ def _renew_prj_dir(namespace_name: str, package_name: str, project_path: str, pr
     if not is_file(file_name):
         _RCS[_rc_id(ae.base, 'write_file')](file_name, f"# runtime dependencies of the {import_name} project")
 
-    file_name = join(project_path, pdv_str(INI_PDV, 'REQ_TEST_FILE_NAME'))
+    file_name = join(project_path, pdv_str(INI_PDV, 'REQ_DEV_FILE_NAME'))
+    # if (not is_file(file_name) or OUTSOURCED_MARKER in read_file(file_name)) and not is_file(file_name + LOCK_EXT):
     if not is_file(file_name) and not is_file(file_name + LOCK_EXT):
         # provide at least basic templates - to allow that this file will be overwritten by a later registered template
-        tpl = join(os.path.dirname(project_path), 'de_tpl_project', tpl_folder, 'de_otf_de_tpl_test_requirements.txt')
+        tpl = join(os.path.dirname(project_path), 'de_tpl_project', tpl_folder, 'de_otf_de_tpl_dev_requirements.txt')
         if is_file(tpl):
             deploy_template(tpl, "", "grm._renew_prj_dir", INI_PDV)
         else:
@@ -1418,7 +1415,7 @@ def _renew_project(project_type: str):
     _git_remote(PRJ_PDV)
 
     if is_portion:
-        _renew_root_req_file(namespace_name, package_name, pdv_str(PRJ_PDV, 'REQ_FILE_NAME'))
+        _renew_root_req_file(namespace_name, package_name, pdv_str(PRJ_PDV, 'REQ_DEV_FILE_NAME'))
 
 
 def _renew_root_req_file(namespace_name: str, package_name: str, req_file: str):
@@ -1452,17 +1449,17 @@ def _template_projects(pdv: PdvType) -> List[RegisteredTemplateProject]:
     namespace_name = pdv_str(pdv, 'namespace_name')
     project_name = pdv_str(pdv, 'project_name')
     project_type = pdv_str(pdv, 'project_type')
-    tests_require = pdv_val(pdv, 'tests_require')
-    debug_msg = f"    * {project_name}: no {{name}} package in {pdv_str(pdv, 'REQ_TEST_FILE_NAME')}->templates blocked!"
+    dev_require = pdv_val(pdv, 'dev_require')
+    debug_msg = f"    * {project_name}: no {{name}} package in {pdv_str(pdv, 'REQ_DEV_FILE_NAME')}->templates blocked!"
 
-    tpl_packages_versions = [_ for _ in tests_require
+    tpl_packages_versions = [_ for _ in dev_require
                              if _ == namespace_name or _.startswith(pdv_str(pdv, 'TPL_PACKAGE_NAME_PREFIX'))]
     _register_project_templates(tpl_packages_versions, namespace_name)
 
     tpl_projects = []   # collect projects of namespace, project type and generic project (highest priority first)
 
     if namespace_name:
-        if namespace_name in tests_require:
+        if namespace_name in dev_require:
             path = package_project_path(namespace_name)
             tpl_projects.append({'import_name': namespace_name, 'path': path,
                                  'version': code_file_version(project_main_file(namespace_name, project_path=path))})
